slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSSetFromOptions

Sets EPS options from the options database. This routine must be called before EPSSetUp() if the user is to be allowed to set the solver type.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSSetFromOptions(EPS eps)

Collective on eps

### Input Parameters

| eps | - the eigensolver context

### Notes

To see all options, run your program with the -help option.

### See Also

EPSSetOptionsPrefix()

### Level

beginner

### Location

src/eps/interface/epsopts.c

### Examples

src/eps/tutorials/ex1.c.html
src/eps/tutorials/ex1f.F.html
src/eps/tutorials/ex1f90.F90.html
src/eps/tutorials/ex2.c.html
src/eps/tutorials/ex3.c.html
src/eps/tutorials/ex4.c.html
src/eps/tutorials/ex5.c.html
src/eps/tutorials/ex6f90.F90.html
src/eps/tutorials/ex7.c.html
src/eps/tutorials/ex9.c.html
src/eps/tutorials/ex10.c.html
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages